@@ -18,8 +18,9 @@ int main(int argc, char **argv) {
 	struct device **baz;
 	int x=0;
     
-	initializeDeviceList(BUS_UNSPEC);
-	baz=probeDevices(CLASS_UNSPEC,BUS_UNSPEC,PROBE_ALL);
+	initializeBusDeviceList(BUS_PCI);
+        initializeDeviceList();
+	baz=probeDevices(CLASS_UNSPEC,BUS_PCI,PROBE_ALL);
 	for (x=0; baz[x]; x++)
 	{
   	/*if(baz[x]->class != CLASS_SCSI) {
